@@ -44,6 +44,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+
 #include "include/forms.h"
 #include "fd_main.h"
 #include "xpm/crab.xpm"
@@ -55,18 +56,15 @@
 #define VN(a)        a,#a
 #define OBJNAME(a)   #a,fl_create_##a,fl_add_##a
 
-typedef struct
-{
+typedef struct {
     int defined;
     char tname[MAX_TYPE_NAME_LEN];
-}
-TDEF;
+} TDEF;
 
 typedef FL_OBJECT *(*FL_ADDPTR) (int, FL_Coord, FL_Coord, FL_Coord,
-				 FL_Coord, const char *);
+								 FL_Coord, const char *);
 
-typedef struct
-{
+typedef struct {
     int cn;
     FL_OBJECT *defobj;		/* default          */
     TDEF types[MAXTYPE];
@@ -77,114 +75,156 @@ typedef struct
     int var_boxtype;		/* means default boxtype may depend on type */
     int default_type;
     const char *default_label;
-}
-CDEF;
+} CDEF;
 
-static CDEF classes[MAXCLASS];
+static CDEF classes[ MAXCLASS ];
 static int cnumb = 0;
 
-typedef FL_OBJECT *(*FL_ADDFREEPTR) (int, FL_Coord, FL_Coord, FL_Coord,
-				     FL_Coord, const char *, FL_HANDLEPTR);
+typedef FL_OBJECT * ( *FL_ADDFREEPTR )( int, FL_Coord, FL_Coord, FL_Coord,
+										FL_Coord, const char *, FL_HANDLEPTR );
+
+
+/***************************************
+ * Adds a class definition
+ ***************************************/
 
-/* Adds a class definition */
 static void
-add_class_def(int numb, char *formal_name, char *name,
-	      FL_ADDPTR createit, FL_ADDPTR addit)
+add_class_def( int       numb,
+			   char *    formal_name,
+			   char *    name,
+			   FL_ADDPTR createit,
+			   FL_ADDPTR addit )
 {
     int i;
 
-    if (cnumb == MAXCLASS)
+    if ( cnumb == MAXCLASS )
     {
-	fprintf(stderr, "exceeding maxclass allowed\n");
-	return;
+		fprintf( stderr, "exceeding maxclass allowed\n" );
+		return;
     }
 
-    classes[cnumb].cn = numb;
-    strcpy(classes[cnumb].cname, name);
-    strcpy(classes[cnumb].formal_cname, formal_name);
-    if (createit)
-	classes[cnumb].defobj = createit(1, 0, 0, 1, 1, "");
-    classes[cnumb].createit = createit;
-    classes[cnumb].addit = addit;
+    classes[ cnumb ].cn = numb;
+    strcpy( classes[ cnumb ].cname, name);
+    strcpy( classes[ cnumb ].formal_cname, formal_name );
+    if ( createit )
+		classes[ cnumb ].defobj = createit( 1, 0, 0, 1, 1, "" );
+    classes[ cnumb ].createit = createit;
+    classes[ cnumb ].addit = addit;
 
-    for (i = 0; i < MAXTYPE; i++)
-	classes[cnumb].types[i].defined = FALSE;
+    for ( i = 0; i < MAXTYPE; i++ )
+		classes[ cnumb ].types[ i ].defined = FALSE;
     cnumb++;
 }
 
+
+/***************************************
+ ***************************************/
+
 static CDEF *
-find_class_struct(int n)
+find_class_struct( int n )
 {
     int i;
-    for (i = 0; i < cnumb; i++)
+
+    for ( i = 0; i < cnumb; i++ )
     {
-	if (classes[i].cn == n)
-	    return classes + i;
+		if ( classes[ i ].cn == n )
+			return classes + i;
     }
-    M_err("FindClassStruct", "Can't find class %d", n);
+    M_err( "find_class_struct", "Can't find class %d", n );
     return 0;
 }
 
 
-/* Adds a type definition to a class */
+/***************************************
+ * Adds a type definition to a class
+ ***************************************/
+
 static void
-add_type_def(int cn, int tn, char name[])
+add_type_def( int  cn,
+			  int  tn,
+			  char name[ ] )
 {
     int i;
 
-    if (tn >= MAXTYPE || tn < 0)
+    if ( tn >= MAXTYPE || tn < 0 )
     {
-	M_err("AddTypeDef", "Bad type: %%d", tn);
-	return;
+		M_err( "add_type_def", "Bad type: %%d", tn );
+		return;
     }
 
-    for (i = 0; i < cnumb; i++)
-    {
-	if (classes[i].cn == cn)
-	{
-	    classes[i].types[tn].defined = TRUE;
-	    strcpy(classes[i].types[tn].tname, name);
-	}
-    }
+    for ( i = 0; i < cnumb; i++ )
+		if ( classes[i].cn == cn )
+		{
+			classes[ i ].types[ tn ].defined = TRUE;
+			strcpy( classes[ i ].types[ tn ].tname, name );
+		}
 }
 
-/* sets a default type and label for class cn */
-static void
-set_class_default(int cn, int def_type, char *label)
-{
-    int i;
-    for (i = 0; i < cnumb; i++)
-    {
-	if (classes[i].cn == cn)
-	{
-	    classes[i].default_type = def_type;
-	    classes[i].default_label = label;	/* note: no copy */
-	}
-    }
-}
+
+/***************************************
+ * sets a default type and label for class cn
+ ***************************************/
 
 static void
-set_var_boxtype(int cn, int yes)
+set_class_default(int    cn,
+				  int    def_type,
+				  char * label )
 {
     int i;
 
     for (i = 0; i < cnumb; i++)
-	if (classes[i].cn == cn)
-	    classes[i].var_boxtype = 1;
+    {
+		if (classes[i].cn == cn)
+		{
+			classes[i].default_type = def_type;
+			classes[i].default_label = label;	/* note: no copy */
+		}
+    }
 }
 
+
+/***************************************
+ ***************************************/
+
+static void
+set_var_boxtype( int cn,
+				 int yes  FL_UNUSED_ARG )
+{
+    int i;
+
+    for (i = 0; i < cnumb; i++)
+		if (classes[i].cn == cn)
+			classes[i].var_boxtype = 1;
+}
+
+
+/***************************************
+ ***************************************/
+
 static FL_OBJECT *
-fd_create_free(int type, FL_Coord x, FL_Coord y, FL_Coord w,
-	       FL_Coord h, const char *l)
+fd_create_free( int          type,
+				FL_Coord     x,
+				FL_Coord     y,
+				FL_Coord     w,
+				FL_Coord     h,
+				const char * l )
 {
-    return fl_create_free(type, x, y, w, h, l, noop_handle);
+    return fl_create_free( type, x, y, w, h, l, noop_handle );
 }
 
+
+/***************************************
+ ***************************************/
+
 static FL_OBJECT *
-fd_add_free(int type, FL_Coord x, FL_Coord y, FL_Coord w,
-	    FL_Coord h, const char *l)
+fd_add_free( int          type,
+			 FL_Coord     x,
+			 FL_Coord     y,
+			 FL_Coord     w,
+			 FL_Coord     h,
+			 const char * l )
 {
-    return fl_add_free(type, x, y, w, h, l, noop_handle);
+    return fl_add_free( type, x, y, w, h, l, noop_handle );
 }
 
 
@@ -192,18 +232,23 @@ fd_add_free(int type, FL_Coord x, FL_Coord y, FL_Coord w,
   CALLBACK ROUTINES
 ****/
 
-/* handles a class change event */
+/***************************************
+ * handles a class change event
+ ***************************************/
+
 void
-object_cb(FL_OBJECT * obj, long arg)
+object_cb( FL_OBJECT * obj,
+		   long        arg  FL_UNUSED_ARG )
 {
     if (fl_get_browser(obj))
-	cur_class = classes[fl_get_browser(obj) - 1].cn;
+		cur_class = classes[fl_get_browser(obj) - 1].cn;
     else
-	cur_class = -1;
+		cur_class = -1;
 
     select_pallette_entry(cur_class);
 }
 
+
 /****
   INITIALIZING THE CLASSES
 ****/
@@ -211,8 +256,11 @@ object_cb(FL_OBJECT * obj, long arg)
 int cur_class = -1;		/* The current class used */
 
 
+/***************************************
+ ***************************************/
+
 static void
-add_button_types(int button_class)
+add_button_types( int button_class )
 {
     add_type_def(button_class, FL_NORMAL_BUTTON, "NORMAL_BUTTON");
     add_type_def(button_class, FL_PUSH_BUTTON, "PUSH_BUTTON");
@@ -225,8 +273,12 @@ add_button_types(int button_class)
     add_type_def(button_class, FL_HIDDEN_RET_BUTTON, "HIDDEN_RET_BUTTON");
 }
 
+
+/***************************************
+ ***************************************/
+
 static void
-add_frame_types(int frame_class)
+add_frame_types( int frame_class )
 {
     add_type_def(frame_class, FL_NO_FRAME, "NO_FRAME");
     add_type_def(frame_class, FL_UP_FRAME, "UP_FRAME");
@@ -239,8 +291,12 @@ add_frame_types(int frame_class)
     add_type_def(frame_class, FL_OVAL_FRAME, "OVAL_FRAME");
 }
 
+
+/***************************************
+ ***************************************/
+
 static void
-add_slider_types(int sclass)
+add_slider_types( int sclass )
 {
     add_type_def(sclass, FL_VERT_SLIDER, "VERT_SLIDER");
     add_type_def(sclass, FL_HOR_SLIDER, "HOR_SLIDER");
@@ -253,16 +309,19 @@ add_slider_types(int sclass)
 }
 
 
-/* Initializes all the classes and types. Must be adapted
-   to add new classes and types.  */
+/***************************************
+ * Initializes all the classes and types. Must be adapted
+ * to add new classes and types.
+ ***************************************/
+
 void
-init_classes(void)
+init_classes( void )
 {
     static int initialized;
     VN_pair *vp;
 
     if (initialized)
-	return;
+		return;
 
     initialized = 1;
 
@@ -271,7 +330,7 @@ init_classes(void)
     fl_add_browser_line(fd_control->objectbrowser, "box");
     add_class_def(VN(FL_BOX), OBJNAME(box));
     for (vp = vn_btype; vp->val >= 0; vp++)
-	add_type_def(FL_BOX, vp->val, vp->name + 3);
+		add_type_def(FL_BOX, vp->val, vp->name + 3);
     set_class_default(FL_BOX, FL_UP_BOX, "");
 
     fl_add_browser_line(fd_control->objectbrowser, "frame");
@@ -374,7 +433,6 @@ init_classes(void)
     add_type_def(FL_SCROLLBAR, FL_VERT_PLAIN_SCROLLBAR, "VERT_PLAIN_SCROLLBAR");
     add_type_def(FL_SCROLLBAR, FL_HOR_PLAIN_SCROLLBAR, "HOR_PLAIN_SCROLLBAR");
 
-
     fl_add_browser_line(fd_control->objectbrowser, "dial");
     add_class_def(VN(FL_DIAL), OBJNAME(dial));
     add_type_def(FL_DIAL, FL_NORMAL_DIAL, "NORMAL_DIAL");
@@ -429,7 +487,6 @@ init_classes(void)
     add_type_def(FL_BROWSER, FL_HOLD_BROWSER, "HOLD_BROWSER");
     add_type_def(FL_BROWSER, FL_MULTI_BROWSER, "MULTI_BROWSER");
 
-
     fl_add_browser_line(fd_control->objectbrowser, "@_timer");
     add_class_def(VN(FL_TIMER), OBJNAME(timer));
     add_type_def(FL_TIMER, FL_NORMAL_TIMER, "NORMAL_TIMER");
@@ -453,34 +510,32 @@ init_classes(void)
     add_type_def(FL_XYPLOT, FL_IMPULSE_XYPLOT, "IMPULSE_XYPLOT");
     add_type_def(FL_XYPLOT, FL_EMPTY_XYPLOT, "EMPTY_XYPLOT");
 
-
     fl_add_browser_line(fd_control->objectbrowser, "canvas");
     add_class_def(VN(FL_CANVAS), "canvas",
-		  fl_create_simu_canvas, fl_add_simu_canvas);
+				  fl_create_simu_canvas, fl_add_simu_canvas);
     add_type_def(FL_CANVAS, FL_NORMAL_CANVAS, "NORMAL_CANVAS");
     add_type_def(FL_CANVAS, FL_SCROLLED_CANVAS, "SCROLLED_CANVAS");
     set_class_default(FL_CANVAS, FL_NORMAL_CANVAS, "");
 
     fl_add_browser_line(fd_control->objectbrowser, "@_glcanvas");
     add_class_def(VN(FL_GLCANVAS), "glcanvas",
-		  fl_create_simu_glcanvas, fl_add_simu_glcanvas);
+				  fl_create_simu_glcanvas, fl_add_simu_glcanvas);
     add_type_def(FL_GLCANVAS, FL_NORMAL_CANVAS, "NORMAL_CANVAS");
     add_type_def(FL_GLCANVAS, FL_SCROLLED_CANVAS, "SCROLLED_CANVAS");
     set_class_default(FL_GLCANVAS, FL_NORMAL_CANVAS, "");
 
     fl_add_browser_line(fd_control->objectbrowser, "tabfolder");
     add_class_def(FL_NTABFOLDER, "FL_TABFOLDER", "tabfolder",
-		  fl_create_ntabfolder, fl_add_ntabfolder);
+				  fl_create_ntabfolder, fl_add_ntabfolder);
     add_type_def(FL_NTABFOLDER, FL_TOP_TABFOLDER, "TOP_TABFOLDER");
     add_type_def(FL_NTABFOLDER, FL_BOTTOM_TABFOLDER, "BOTTOM_TABFOLDER");
     set_class_default(FL_NTABFOLDER, FL_TOP_TABFOLDER, "");
 
     fl_add_browser_line(fd_control->objectbrowser, "@_formbrowser");
     add_class_def(FL_FORMBROWSER, "FL_FORMBROWSER", "formbrowser",
-		  fl_create_nformbrowser, fl_add_nformbrowser);
+				  fl_create_nformbrowser, fl_add_nformbrowser);
     add_type_def(FL_FORMBROWSER, FL_NORMAL_FORMBROWSER, "NORMAL_FORMBROWSER");
 
-
     fl_add_browser_line(fd_control->objectbrowser, "freeobject");
     add_class_def(VN(FL_FREE), "free", fd_create_free, fd_add_free);
     add_type_def(FL_FREE, FL_NORMAL_FREE, "NORMAL_FREE");
@@ -491,9 +546,8 @@ init_classes(void)
 
     /* ADD NEW CLASSES HERE */
 
-
-
     /* group must be last. palette.c need this */
+
     add_class_def(VN(FL_BEGIN_GROUP), "group", 0, 0);
     add_type_def(FL_BEGIN_GROUP, 0, "0");
 
@@ -501,19 +555,23 @@ init_classes(void)
     add_type_def(FL_END_GROUP, 0, "0");
 }
 
+
+/***************************************
+ ***************************************/
+
 void
-select_object_by_class(int cn)
+select_object_by_class( int cn )
 {
     int i;
 
     for (i = 0; i < cnumb; i++)
-	if (classes[i].cn == cn)
-	{
-	    fl_select_browser_line(fd_control->objectbrowser, i + 1);
-	    fl_show_browser_line(fd_control->objectbrowser, i + 1);
-	    cur_class = cn;
-	    break;
-	}
+		if (classes[i].cn == cn)
+		{
+			fl_select_browser_line(fd_control->objectbrowser, i + 1);
+			fl_show_browser_line(fd_control->objectbrowser, i + 1);
+			cur_class = cn;
+			break;
+		}
 }
 
 
@@ -521,126 +579,162 @@ select_object_by_class(int cn)
   GETTING INFORMATION ABOUT CLASSES AND TYPES
 ****/
 
-/* Returns a pointer to the (short) name of the class */
+/***************************************
+ * Returns a pointer to the (short) name of the class
+ ***************************************/
+
 char *
-find_class_name(int cln)
+find_class_name( int cln )
 {
     int i;
-    static char buf[MAX_CLASS_NAME_LEN];
+    static char buf[ MAX_CLASS_NAME_LEN ];
+
     for (i = 0; i < cnumb; i++)
-	if (classes[i].cn == cln)
-	    return classes[i].cname;
+		if (classes[i].cn == cln)
+			return classes[i].cname;
     sprintf(buf, "%d", cln);
     return buf;
 }
 
-/* return a pointer to the formal name of the class */
+
+/***************************************
+ * return a pointer to the formal name of the class
+ ***************************************/
+
 char *
-class_name(int cls)
+class_name( int cls )
 {
     int i;
     static char buf[MAX_CLASS_NAME_LEN];
+
     for (i = 0; i < cnumb; i++)
-	if (classes[i].cn == cls)
-	    return classes[i].formal_cname;
+		if (classes[i].cn == cls)
+			return classes[i].formal_cname;
     sprintf(buf, "%d", cls);
     return buf;
 }
 
-/* return the class value */
+
+/***************************************
+ * return the class value
+ ***************************************/
+
 int
-class_val(const char *name)
+class_val( const char * name )
 {
     int i;
 
-    for (i = 0; i < cnumb; i++)
+    for ( i = 0; i < cnumb; i++ )
     {
-	if (strcmp(classes[i].cname, name) == 0 ||
-	    strcmp(classes[i].formal_cname, name) == 0)
-	    return classes[i].cn;
+		if (    strcmp( classes[ i ].cname, name ) == 0
+			 || strcmp( classes[ i ].formal_cname, name ) == 0 )
+			return classes[ i ].cn;
     }
 
-    return atoi(name);
+    return atoi( name );
 }
 
-/* Returns a pointer to the default object of the class. var_boxtype
+
+/***************************************
+ * Returns a pointer to the default object of the class. var_boxtype
  * means different type may have different boxtypes
- */
+ ***************************************/
 
 FL_OBJECT *
-find_class_default(int cln, int t)
+find_class_default( int cln,
+					int t )
 {
     int i;
     CDEF *c = classes;
 
-    for (i = 0; i < cnumb; i++, c++)
-	if (c->cn == cln)
-	{
-	    if (c->var_boxtype)
-	    {
-		if (c->defobj1)
-		    fl_free_object(c->defobj1);
-		return c->defobj1 = c->createit(t, 0, 0, 1, 1, "");
-	    }
-	    else
-		return c->defobj;
-	}
+    for ( i = 0; i < cnumb; i++, c++ )
+		if ( c->cn == cln )
+		{
+			if ( c->var_boxtype )
+			{
+				if ( c->defobj1 )
+					fl_free_object( c->defobj1 );
+				return c->defobj1 = c->createit( t, 0, 0, 1, 1, "" );
+			}
+			else
+				return c->defobj;
+		}
+
     return NULL;
 }
 
-/* Returns the number of types in the class */
+
+/***************************************
+ * Returns the number of types in the class
+ ***************************************/
+
 int
-find_class_maxtype(int cln)
+find_class_maxtype( int cln )
 {
     int i, j, n = 0;
+
     for (i = 0; i < cnumb; i++)
-	if (classes[i].cn == cln)
-	    for (j = 0; j < MAXTYPE; j++)
-		if (classes[i].types[j].defined)
-		    n++;
+		if (classes[i].cn == cln)
+			for (j = 0; j < MAXTYPE; j++)
+				if (classes[i].types[j].defined)
+					n++;
     return n;
 }
 
-/* Returns a pointer to the name of the type in the class */
+
+/***************************************
+ * Returns a pointer to the name of the type in the class
+ ***************************************/
+
 const char *
-find_type_name(int cln, int tyn)
+find_type_name( int cln,
+				int tyn )
 {
     int i;
     static char buf[MAX_TYPE_NAME_LEN];
 
     for (i = 0; i < cnumb; i++)
-	if (classes[i].cn == cln)
-	    return classes[i].types[tyn].tname;
+		if (classes[i].cn == cln)
+			return classes[i].types[tyn].tname;
     sprintf(buf, "%d", tyn);
     return buf;
 }
 
-/* returns a integer indicating the value of a type */
+
+/***************************************
+ * returns a integer indicating the value of a type
+ ***************************************/
+
 int
-find_type_value(int cln, const char *tyname)
+find_type_value( int          cln,
+				 const char * tyname )
 {
     int i, jmax = find_class_maxtype(cln), j;
+
     for (i = 0; i < cnumb; i++)
     {
-	if (classes[i].cn == cln)
-	{
-	    for (j = 0; j < jmax; j++)
-	    {
-		if (strcmp(classes[i].types[j].tname, tyname) == 0)
-		    return j;
-	    }
-	}
+		if (classes[i].cn == cln)
+		{
+			for (j = 0; j < jmax; j++)
+			{
+				if (strcmp(classes[i].types[j].tname, tyname) == 0)
+					return j;
+			}
+		}
     }
+
     M_err("TypeValue", "type %s is unknown", tyname);
     return atoi(tyname);
 }
 
+
 /****
   ADDING OBJECTS
 ****/
 
 #define bm1_width 16
 #define bm1_height 16
+
 static unsigned char bm1_bits[] =
 {
     0x00, 0x00, 0x00, 0x57, 0x7c, 0x72, 0xc4, 0x52, 0xc4, 0x00, 0x44, 0x01,
@@ -653,186 +747,231 @@ static unsigned char bm1_bits[] =
 #define pm_height 28
 
 
+/***************************************
+ ***************************************/
+
 void
-set_testing_pixmap(FL_OBJECT * ob)
+set_testing_pixmap( FL_OBJECT * ob )
 {
-    fl_set_pixmap_data(ob, crab);
+    fl_set_pixmap_data( ob, crab );
 }
 
 
-/* adds an object to the current form  type = -1 means default type */
+/***************************************
+ * adds an object to the current form  type = -1 means default type
+ ***************************************/
+
 FL_OBJECT *
-add_an_object(int objclass, int type, FL_Coord x, FL_Coord y, FL_Coord w, FL_Coord h)
+add_an_object( int      objclass,
+			   int      type,
+			   FL_Coord x,
+			   FL_Coord y,
+			   FL_Coord w,
+			   FL_Coord h )
 {
-    FL_OBJECT *obj = 0;
+    FL_OBJECT *obj = NULL;
     int nosuper = 0, i;
     char buf[128];
     CDEF *cls;
+	static FL_FORM *cf = NULL;
 
-    if (cur_form == NULL)
-	return NULL;
+    if ( cur_form == NULL )
+		return NULL;
 
     /* this routine is called with X coordinate system, need to translate to
        up-right coordinate system */
 
-    if (!(cls = find_class_struct(objclass)))
+    if ( ! ( cls = find_class_struct( objclass ) ) )
     {
-	fprintf(stderr, "unknown class %d\n", objclass);
-	return 0;
+		fprintf( stderr, "unknown class %d\n", objclass );
+		return 0;
     }
 
-    fl_addto_form(cur_form);
+	if ( ! cf )
+		fl_addto_form( cur_form );
 
-    switch (objclass)
+    switch ( objclass )
     {
-    case FL_BEGIN_GROUP:
-	obj = fl_bgn_group();
-	break;
-    case FL_END_GROUP:
-	obj = fl_end_group();
-	break;
-    case FL_BITMAP:
-	if (type == -1)
-	    type = FL_NORMAL_BITMAP;
-	obj = cls->addit(type, x, y, w, h, "");
-	if (!fdopt.conv_only)
-	    fl_set_bitmap_data(obj, bm1_width, bm1_height, bm1_bits);
-	break;
-    case FL_PIXMAP:
-	if (type == -1)
-	    type = FL_NORMAL_PIXMAP;
-	obj = cls->addit(type, x, y, w, h, "");
-	if (!fdopt.conv_only)
-	    fl_set_pixmap_data(obj, crab);
-	break;
-    case FL_CHART:
-	if (type == -1)
-	    type = FL_BAR_CHART;
-	obj = cls->addit(type, x, y, w, h, "");
-	fl_add_chart_value(obj, 4.0, "item 1", 2);
-	fl_add_chart_value(obj, 8.0, "item 2", 3);
-	fl_add_chart_value(obj, 2.0, "item 3", 4);
-	fl_add_chart_value(obj, 5.0, "item 4", 5);
-	break;
-    case FL_BITMAPBUTTON:
-	if (type == -1)
-	    type = FL_NORMAL_BUTTON;
-	obj = cls->addit(type, x, y, w, h, "");
-	if (!fdopt.conv_only)
-	    fl_set_bitmapbutton_data(obj, bm1_width, bm1_height, bm1_bits);
-	break;
-    case FL_PIXMAPBUTTON:
-	if (type == -1)
-	    type = FL_NORMAL_BUTTON;
-	obj = cls->addit(type, x, y, w, h, "");
-	if (!fdopt.conv_only)
-	    fl_set_pixmapbutton_data(obj, crab);
-	break;
-    case FL_SLIDER:
-	if (type == -1)
-	    type = (h > w) ? FL_VERT_BROWSER_SLIDER : FL_HOR_BROWSER_SLIDER;
-	obj = cls->addit(type, x, y, w, h, "");
-	break;
-    case FL_VALSLIDER:
-	if (type == -1)
-	    type = (h > w) ? FL_VERT_BROWSER_SLIDER : FL_HOR_BROWSER_SLIDER;
-	obj = cls->addit(type, x, y, w, h, "");
-	break;
-    case FL_SCROLLBAR:
-	if (type == -1)
-	    type = (h > w) ? FL_VERT_SCROLLBAR : FL_HOR_SCROLLBAR;
-	obj = cls->addit(type, x, y, w, h, "");
-	break;
-    case FL_THUMBWHEEL:
-	if (type == -1)
-	    type = (h > w) ? FL_VERT_THUMBWHEEL : FL_HOR_THUMBWHEEL;
-	obj = cls->addit(type, x, y, w, h, "");
-	break;
-    case FL_INPUT:
-	if (type == -1)
-	    type = h < 60 ? FL_NORMAL_INPUT : FL_MULTILINE_INPUT;
-	obj = cls->addit(type, x, y, w, h, "Input");
-	fl_set_input_hscrollbar(obj, FL_OFF);
-	fl_set_input_vscrollbar(obj, FL_OFF);
-	break;
-    case FL_MENU:
-	if (type == -1)
-	    type = FL_PULLDOWN_MENU;
-	obj = cls->addit(type, x, y, w, h, "Menu");
-	spec_to_superspec(obj);
-	nosuper = 1;
-	fl_addto_menu(obj, "menuitem 1");
-	fl_addto_menu(obj, "menuitem 2");
-	fl_addto_menu(obj, "menuitem 3");
-	fl_addto_menu(obj, "menuitem 4");
-	break;
-    case FL_CHOICE:
-	if (type == -1)
-	    type = FL_NORMAL_CHOICE2;
-	obj = cls->addit(type, x, y, w, h, "");
-	spec_to_superspec(obj);
-	nosuper = 1;
+		case FL_BEGIN_GROUP:
+			cf = cur_form;
+			obj = fl_bgn_group( );
+			break;
 
-	fl_addto_choice(obj, "choice 1");
-	fl_addto_choice(obj, "choice 2");
-	fl_addto_choice(obj, "choice 3");
-	fl_addto_choice(obj, "choice 4");
-	break;
-    case FL_BROWSER:
-	if (type == -1)
-	    type = FL_NORMAL_BROWSER;
-	obj = cls->addit(type, x, y, w, h, "");
-	spec_to_superspec(obj);
-	nosuper = 1;
+		case FL_END_GROUP:
+			obj = fl_end_group( );
+			break;
 
-	for (i = 0; i < 30; i++)
-	{
-	    sprintf(buf, "Browser line %d", i + 1);
-	    fl_add_browser_line(obj, buf);
-	}
-	break;
-    case FL_XYPLOT:
-	if (type == -1)
-	    type = FL_NORMAL_XYPLOT;
-	{
-	    float xx[30], yy[30];
-	    int ii;
+		case FL_BITMAP:
+			if ( type == -1 )
+				type = FL_NORMAL_BITMAP;
+			obj = cls->addit( type, x, y, w, h, "" );
+			if ( ! fdopt.conv_only )
+				fl_set_bitmap_data( obj, bm1_width, bm1_height, bm1_bits );
+			break;
 
-	    for (ii = 0; ii < 30; ii++)
-	    {
-		xx[ii] = 3.1415 * (ii + 0.5) / 8.0;
-		yy[ii] = sin(2 * xx[ii]) + cos(xx[ii]);
-		yy[ii] = FL_abs(yy[ii]);
-	    }
+		case FL_PIXMAP:
+			if ( type == -1 )
+				type = FL_NORMAL_PIXMAP;
+			obj = cls->addit( type, x, y, w, h, "" );
+			if ( ! fdopt.conv_only )
+				fl_set_pixmap_data( obj, crab );
+			break;
 
-	    obj = cls->addit(type, x, y, w, h, "");
-/*          fl_set_xyplot_data(obj, xx, yy, 30, "XyPlot", "X-axis", "Y"); */
-	    fl_set_xyplot_data(obj, xx, yy, 30, "", "", "");
-	}
-	break;
+		case FL_CHART:
+			if ( type == -1 )
+				type = FL_BAR_CHART;
+			obj = cls->addit( type, x, y, w, h, "" );
+			fl_add_chart_value( obj, 4.0, "item 1", 2 );
+			fl_add_chart_value( obj, 8.0, "item 2", 3 );
+			fl_add_chart_value( obj, 2.0, "item 3", 4 );
+			fl_add_chart_value( obj, 5.0, "item 4", 5 );
+			break;
 
-    case FL_FREE:
-	if (type == -1)
-	    type = FL_NORMAL_FREE;
-	obj = fl_add_free(type, x, y, w, h, "", noop_handle);
-	break;
+		case FL_BITMAPBUTTON:
+			if ( type == -1 )
+				type = FL_NORMAL_BUTTON;
+			obj = cls->addit( type, x, y, w, h, "" );
+			if ( ! fdopt.conv_only )
+				fl_set_bitmapbutton_data( obj, bm1_width, bm1_height,
+										  bm1_bits );
+			break;
 
-    default:
-	if (type == -1)
-	    type = cls->default_type;
-	obj = cls->addit(type, x, y, w, h, cls->default_label);
-	break;
+		case FL_PIXMAPBUTTON:
+			if ( type == -1 )
+				type = FL_NORMAL_BUTTON;
+			obj = cls->addit( type, x, y, w, h, "" );
+			if ( ! fdopt.conv_only )
+				fl_set_pixmapbutton_data( obj, crab );
+			break;
+
+		case FL_SLIDER:
+			if ( type == -1 )
+				type = h > w ? FL_VERT_BROWSER_SLIDER : FL_HOR_BROWSER_SLIDER;
+			obj = cls->addit( type, x, y, w, h, "" );
+			break;
+
+		case FL_VALSLIDER:
+			if ( type == -1 )
+				type = h > w ? FL_VERT_BROWSER_SLIDER : FL_HOR_BROWSER_SLIDER;
+			obj = cls->addit( type, x, y, w, h, "" );
+			break;
+
+		case FL_SCROLLBAR:
+			if ( type == -1 )
+				type = h > w ? FL_VERT_SCROLLBAR : FL_HOR_SCROLLBAR;
+			obj = cls->addit( type, x, y, w, h, "" );
+			break;
+
+		case FL_THUMBWHEEL:
+			if ( type == -1 )
+				type = h > w ? FL_VERT_THUMBWHEEL : FL_HOR_THUMBWHEEL;
+			obj = cls->addit( type, x, y, w, h, "" );
+			break;
+
+		case FL_INPUT:
+			if ( type == -1 )
+				type = h < 60 ? FL_NORMAL_INPUT : FL_MULTILINE_INPUT;
+			obj = cls->addit( type, x, y, w, h, "Input" );
+			fl_set_input_hscrollbar( obj, FL_OFF );
+			fl_set_input_vscrollbar( obj, FL_OFF );
+			break;
+
+		case FL_MENU:
+			if ( type == -1 )
+				type = FL_PULLDOWN_MENU;
+			obj = cls->addit( type, x, y, w, h, "Menu" );
+			spec_to_superspec( obj );
+			nosuper = 1;
+			fl_addto_menu( obj, "menuitem 1" );
+			fl_addto_menu( obj, "menuitem 2" );
+			fl_addto_menu( obj, "menuitem 3" );
+			fl_addto_menu( obj, "menuitem 4" );
+			break;
+
+		case FL_CHOICE:
+			if ( type == -1 )
+				type = FL_NORMAL_CHOICE2;
+			obj = cls->addit( type, x, y, w, h, "" );
+			spec_to_superspec( obj );
+			nosuper = 1;
+
+			fl_addto_choice( obj, "choice 1" );
+			fl_addto_choice( obj, "choice 2" );
+			fl_addto_choice( obj, "choice 3" );
+			fl_addto_choice( obj, "choice 4" );
+			break;
+
+		case FL_BROWSER:
+			if ( type == -1 )
+				type = FL_NORMAL_BROWSER;
+			obj = cls->addit( type, x, y, w, h, "" );
+			spec_to_superspec( obj );
+			nosuper = 1;
+
+			for ( i = 0; i < 30; i++ )
+			{
+				sprintf( buf, "Browser line %d", i + 1 );
+				fl_add_browser_line( obj, buf );
+			}
+			break;
+
+		case FL_XYPLOT:
+			if (type == -1)
+				type = FL_NORMAL_XYPLOT;
+			{
+				float xx[30], yy[30];
+				int ii;
+
+				for (ii = 0; ii < 30; ii++)
+				{
+					xx[ii] = 3.1415 * (ii + 0.5) / 8.0;
+					yy[ii] = sin(2 * xx[ii]) + cos(xx[ii]);
+					yy[ii] = FL_abs(yy[ii]);
+				}
+
+				obj = cls->addit(type, x, y, w, h, "");
+				/* fl_set_xyplot_data(obj, xx, yy, 30, "XyPlot", "X-axis", "Y"); */
+				fl_set_xyplot_data(obj, xx, yy, 30, "", "", "");
+			}
+			break;
+
+		case FL_FREE:
+			if (type == -1)
+				type = FL_NORMAL_FREE;
+			obj = fl_add_free(type, x, y, w, h, "", noop_handle);
+			break;
+
+		default:
+			if (type == -1)
+				type = cls->default_type;
+			obj = cls->addit(type, x, y, w, h, cls->default_label);
+			break;
     }
 
-    if (!obj)
-	fprintf(stderr, "Unknown object(class=%d type=%d)\n", objclass, type);
+    if ( ! obj )
+		fprintf( stderr, "Unknown object(class=%d type=%d)\n",
+				 objclass, type );
 
-    fl_end_form();
+	obj->fl1 = obj->x;
+	obj->fr1 = cur_form->w_hr - obj->fl1;
+	obj->ft1 = obj->y;
+	obj->fb1 = cur_form->h_hr - obj->ft1;
 
-    if (!nosuper)
-	get_superspec(obj);
+	obj->fl2 = obj->x + obj->w;
+	obj->fr2 = cur_form->w - obj->fl2;
+	obj->ft2 = obj->y + obj->h;
+	obj->fb2 = cur_form->h - obj->ft2;
 
-    obj->active = TRUE;
+	if ( ! cf || objclass == FL_END_GROUP )
+	{
+		fl_end_form( );
+		cf = NULL;
+	}
+
+    if ( ! nosuper )
+		get_superspec( obj );
+
+    obj->active = 1;
 
     return obj;
 }
