@@ -1,6 +1,6 @@
 /*
  *
- *  This file is part of the XForms library package.
+ *	This file is part of the XForms library package.
  *
  * XForms is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as
@@ -9,11 +9,11 @@
  *
  * XForms is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with XForms; see the file COPYING.  If not, write to
+ * License along with XForms; see the file COPYING.	 If not, write to
  * the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
  * MA 02111-1307, USA.
  *
@@ -25,31 +25,30 @@
  * \file box.h
  *
  */
+
 #ifndef FL_BOX_H
 #define FL_BOX_H
 
 
 /* type already defined in Basic.h */
 
+FL_EXPORT FL_OBJECT * fl_create_box(
+		int			 type,
+		FL_Coord	 x,
+		FL_Coord	 y,
+		FL_Coord	 w,
+		FL_Coord	 h,
+		const char * label
+		);
 
-FL_EXPORT FL_OBJECT *fl_create_box(
-		int type,
-		FL_Coord x,
-		FL_Coord y,
-		FL_Coord w,
-		FL_Coord h,
-		const char *label
+FL_EXPORT FL_OBJECT * fl_add_box(
+		int			 type,
+		FL_Coord	 x,
+		FL_Coord	 y,
+		FL_Coord	 w,
+		FL_Coord	 h,
+		const char * label
 		);
 
 
-FL_EXPORT FL_OBJECT *fl_add_box(
-		int type,
-		FL_Coord x,
-		FL_Coord y,
-		FL_Coord w,
-		FL_Coord h,
-		const char *label
-		);
-
-
-#endif
+#endif /* ! defined FL_BOX_H */
