@@ -23,6 +23,7 @@
  * \file flsnprintf.h
  *
  */
+
 #ifndef FL_SNPRINTF_H
 #define FL_SNPRINTF_H
 
@@ -31,10 +32,16 @@
 #ifdef HAVE_SNPRINTF
 
 #ifndef HAVE_DECL_SNPRINTF
-int snprintf(char *, size_t, const char *, ...);
+int snprintf( char *,
+			  size_t,
+			  const char *,
+			  ...);
 #endif
 #ifndef HAVE_DECL_VSNPRINTF
-int vsnprintf(char *, size_t, const char *, va_list);
+int vsnprintf( char *,
+			   size_t,
+			   const char *,
+			   va_list);
 #endif
 
 #define fl_snprintf  snprintf
@@ -42,8 +49,15 @@ int vsnprintf(char *, size_t, const char *, va_list);
 
 #else /* HAVE_SNPRINTF */
 
-FL_EXPORT int fl_portable_snprintf(char *, size_t, const char *, ...);
-FL_EXPORT int fl_portable_vsnprintf(char *, size_t, const char *, va_list);
+FL_EXPORT int fl_portable_snprintf( char *,
+									size_t,
+									const char *,
+									... );
+
+FL_EXPORT int fl_portable_vsnprintf( char *,
+									 size_t,
+									 const char *,
+									 va_list );
 
 #define fl_snprintf  fl_portable_snprintf
 #define fl_vsnprintf fl_portable_vsnprintf
