@@ -29,11 +29,14 @@
  *  private header for counter objects
  *
  */
+
 #ifndef PCOUNTER_H
 #define PCOUNTER_H
 
 #include "pvaluator.h"
 
-typedef FL_VALUATOR_SPEC FL_COUNTER_SPEC;
+
+typedef FLI_VALUATOR_SPEC FLI_COUNTER_SPEC;
+
 
 #endif /* PCOUNTER_H */
