@@ -22,16 +22,21 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+
 #include <stdio.h>
 #include "include/forms.h"
 #include "flinternal.h"
 #include "ulib.h"
 
+
+/***************************************
+ ***************************************/
+
 int
-fl_fget4LSBF(FILE * fp)
+fli_fget4LSBF( FILE * fp )
 {
-    register int ret;
-    ret = getc(fp);
+    int ret  = getc(fp);
+
     ret |= getc(fp) << 8;
     ret |= getc(fp) << 16;
     ret |= getc(fp) << 24;
@@ -39,8 +44,12 @@ fl_fget4LSBF(FILE * fp)
 }
 
 
+/***************************************
+ ***************************************/
+
 int
-fl_fput4LSBF(register int code, FILE * fp)
+fli_fput4LSBF( int    code,
+			  FILE * fp )
 {
     putc(code & 0xff, fp);
     putc((code >> 8) & 0xff, fp);
