@@ -33,14 +33,20 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+
 #include <stdlib.h>
 #include <string.h>
 #include "include/forms.h"
 #include "flinternal.h"
 
+
+/***************************************
+ ***************************************/
+
 char *
-fl_strdup(const char *s)
+fl_strdup( const char * s )
 {
-    char *p = fl_malloc(1 + strlen(s));
-    return p ? strcpy(p, s) : p;
+    char *p = fl_malloc( strlen( s ) + 1 );
+
+    return p ? strcpy( p, s ) : p;
 }
